@@ -1,6 +1,7 @@
 import logging
 logger = logging.getLogger(__name__)
 from io import BytesIO
+import datetime
 import itertools
 import magic
 from PIL import Image, UnidentifiedImageError
@@ -17,54 +18,23 @@ from django.conf import settings
 from django_drf_filepond.api import store_upload, get_stored_upload_file_data
 from django_drf_filepond.models import TemporaryUpload
 
-from .models import MediaGallery, Video
+from .models import MediaGallery as Album, Video
 from photologue.models import Photo
 
-class BulkMediaForm(forms.Form):
-    gallery = forms.ModelChoiceField(MediaGallery.objects.all(),
-                                     label=_('Gallery'),
-                                     required=False,
-                                     help_text=_('Select a gallery to add these images to. Leave this empty to '
-                                                 'create a new gallery from the supplied title.'))
-    gallery_title = forms.CharField(label='Gallery Title', max_length=100, required=False)
-
-    media_title = forms.CharField(label=_('Default Media Title'),
-                            max_length=250,
-                            required=False,
-                            help_text=_('All uploaded media will be given a title made up of this title + a '
-                                        'sequential number.<br>This field is required if creating a new '
-                                        'gallery, but is optional when adding to an existing gallery - if '
-                                        'not supplied, the photo titles will be creating from the existing '
-                                        'gallery name.'))
+CURRENT_SITE = Site.objects.get(id=settings.SITE_ID)
 
+class MediaForm(forms.Form):
     description = forms.CharField(label=_('Description'),
                                   required=False,
                                   help_text=_('A description of this Gallery. Only required for new galleries.'))
 
-    is_public = forms.BooleanField(label=_('Is public'),
+    is_public = forms.BooleanField(label=_('Public'),
                                    initial=True,
                                    required=False,
                                    help_text=_('Uncheck this to make the uploaded '
                                                'gallery and included photographs private.'))
     filepond = SimpleArrayField(forms.CharField(max_length=255), widget=forms.HiddenInput(),
-            required=False)
-    date_added = forms.DateField(widget=AdminDateWidget(), label="Date")
-
-    def clean_title(self):
-        gallery_title = self.cleaned_data['gallery_title']
-        if gallery_title and MediaGallery.objects.filter(title=gallery_title).exists():
-            raise forms.ValidationError(_('A gallery with that title already exists.'))
-        return gallery_title
-
-    def clean(self):
-        cleaned_data = super().clean()
-        if not self['gallery_title'].errors:
-            # If there's already an error in the title, no need to add another
-            # error related to the same field.
-            if not cleaned_data.get('gallery_title', None) and not cleaned_data['gallery']:
-                raise forms.ValidationError(
-                    _('Select an existing gallery, or enter a title for a new gallery.'))
-        return cleaned_data
+           required=False)
 
     def _generate_slug(self, title):
         slug_candidate = slug_original = slugify(title)
@@ -76,24 +46,10 @@ class BulkMediaForm(forms.Form):
             slug_candidate = '{}-{}'.format(slug_original, i)
         return slug_candidate, num_found
 
-    def save(self):
+    def save(self, gallery):
         filelist = self.cleaned_data['filepond']
 
-        current_site = Site.objects.get(id=settings.SITE_ID)
-        if self.cleaned_data['gallery']:
-            logger.debug('Using pre-existing gallery.')
-            gallery = self.cleaned_data['gallery']
-        else:
-            logger.debug('Creating new gallery "{0}".'.format(self.cleaned_data['gallery_title']))
-            gallery = MediaGallery.objects.create(title=self.cleaned_data['gallery_title'],
-                                             date_added=self.cleaned_data['date_added'],
-                                             slug=slugify(self.cleaned_data['gallery_title']),
-                                             description=self.cleaned_data['description'],
-                                             is_public=self.cleaned_data['is_public'])
-            gallery.sites.add(current_site)
-
-	# This is where we diverge from photologue 
-	# Here we are reading a list of filepond IDS which we will then import
+	# read list of filepond IDS which we will then import
 	# via store_upload from drf-filepond: https://tinyurl.com/3t3623b2
         for upload_id in filelist:
             logger.debug('Reading file "{}".'.format(upload_id))
@@ -106,7 +62,7 @@ class BulkMediaForm(forms.Form):
                 logger.debug('File "{}" is empty.'.format(filename))
                 continue
 
-            media_title_root = numbered_title = self.cleaned_data['media_title'] if self.cleaned_data['media_title'] else gallery.title
+            media_title_root = numbered_title = gallery.title
 
             # A photo might already exist with the same slug. So it's somewhat inefficient,
             # but we loop until we find a slug that's available.
@@ -120,19 +76,45 @@ class BulkMediaForm(forms.Form):
                 logger.info("image mimetype detected")
                 photo = Photo(title=numbered_title,
                               slug=slug,
-                              date_added=self.cleaned_data['date_added'],
                               is_public=self.cleaned_data['is_public'])
 
                 photo.image = "photologue/{}".format(upload_id)
                 photo.save()
-                photo.sites.add(current_site)
+                photo.sites.add(CURRENT_SITE)
                 gallery.photos.add(photo)
             elif file_mimetype == "video":
                 logger.info("video mimetype detected")
-                video = Video(title=numbered_title, slug=slug, date_added=self.cleaned_data['date_added'], is_public=self.cleaned_data['is_public'])
+                video = Video(title=numbered_title, slug=slug, is_public=self.cleaned_data['is_public'])
                 video.file = "photologue/{}".format(upload_id)
                 video.save()
                 gallery.videos.add(video)
             else:
                 logger.error('cound not process file "{}"'.format(filename))
         return gallery.slug
+
+class NewAlbumForm(MediaForm):
+    gallery_title = forms.CharField(label='Album Title', max_length=100, required=False)
+
+    field_order = ['gallery_title', 'is_public', 'description', 'filepond',]
+
+    def clean_title(self):
+        gallery_title = self.cleaned_data['gallery_title']
+        if Album.objects.filter(title=gallery_title).exists():
+            raise forms.ValidationError(_('A gallery with that title already exists.'))
+        return gallery_title
+
+    def save(self):
+        gallery = Album.objects.create(title=self.cleaned_data['gallery_title'],
+                                              slug=slugify(self.cleaned_data['gallery_title']),
+                                              description=self.cleaned_data['description'],
+                                              is_public=self.cleaned_data['is_public'])
+        gallery.sites.add(CURRENT_SITE)
+        return super(NewAlbumForm, self).save(gallery)
+
+class EditAlbumForm(MediaForm):
+    gallery = forms.ModelChoiceField(Album.objects.all(),
+                                     label=_('Gallery'),
+                                     required=True,
+                                     help_text=_('Select a gallery to add these images to. Leave this empty to '
+                                                 'create a new gallery from the supplied title.'))
+
